Activation functions
------------------------

.. automodule:: flax.nnx
.. currentmodule:: flax.nnx

.. autofunction:: celu
.. autofunction:: elu
.. autofunction:: gelu
.. autofunction:: glu
.. autofunction:: hard_sigmoid
.. autofunction:: hard_silu
.. autofunction:: hard_swish
.. autofunction:: hard_tanh
.. autofunction:: leaky_relu
.. autofunction:: log_sigmoid
.. autofunction:: log_softmax
.. autofunction:: logsumexp
.. autofunction:: one_hot
.. autofunction:: relu
.. autofunction:: relu6 as relu6,
.. autofunction:: selu
.. autofunction:: sigmoid
.. autofunction:: silu
.. autofunction:: soft_sign
.. autofunction:: softmax
.. autofunction:: softplus
.. autofunction:: standardize
.. autofunction:: swish
.. autofunction:: tanh